@@ -11,7 +11,7 @@ class Question:
     """
     The question type returned when getting questions
     """
-    __slots__ = ('category', 'type', 'question', 'answer', 'incorrect_answers')
+    __slots__ = ('category', 'type', 'question', 'answer', 'incorrect_answers', 'difficulty')
 
     def __init__(self, data: dict):
         self.category = data.get('category')
@@ -19,6 +19,7 @@ class Question:
         self.question = unescape(str(data.get('question')))
         self.answer = unescape(str(data.get('correct_answer')))
         self.incorrect_answers: list = [unescape(answer) for answer in data.get('incorrect_answers')]
+        self.difficulty = data.get('difficulty')
 
     def __repr__(self):
         return f"<aiotrivia.question.Question: question={self.question}, category={self.category}, type={self.type}>"
